import sys
import subprocess
import importlib
import xhlog as log

def index():
    help = R"""ApiCat-接口猫
使用：
apicat [命令]
        
命令：
help    显示帮助信息
init    初始化项目
install 安装apicat插件
start   启动项目"""
    try:
        if sys.argv[1] == "help":
            print(help)
        if sys.argv[1] == "init":
            init()
        elif sys.argv[1] == "start":
            start()
    except IndexError:
        print(help)

def init():
    with open("__init__.py","w",encoding="utf-8") as f:
        run_code = R"""from apicat import app,core,config
import xhlog as log
log.info("欢迎使用 ApiCat🎉")
log.info("开发团队: 星海码队")
log.info("项目地址: https://github.com/xinghai-osc/apicat")
core.register_plugins(app)
if config.get_website_name() == "ApiCat":
    log.warning(f"网站名称未设置！默认为 ApiCat，请前往配置文件修改。")
app.run(port=config.get_port(), host=config.get_host())
        """
        log.info("项目初始化-运行入口")
        f.write(run_code)
    with open("config.toml","w",encoding="utf-8") as f:
        default_config = R"""[website]
name = "ApiCat"
port = 80
host = "0.0.0.0"
url = "http://localhost"
        """
        log.info("项目初始化-默认配置")
        f.write(default_config)
    with open("plugins.yaml","w",encoding="utf-8") as f:
        log.info("项目初始化-插件配置文件")
        f.write("")
        log.info("项目初始化成功！")

def install(pkg_name):
    """安装插件"""
    subprocess.call(f"pip install {pkg_name}", shell=True)
    pkg_import = importlib.import_module(pkg_name)
    with open("plugins.yaml","a",encoding="utf-8") as f:
        f.write(f"{pkg_import.install()}\n")
    log.info(f"插件 {pkg_name} 安装成功！")

def start():
    """启动API"""
    subprocess.call("python __init__.py", shell=True)

if __name__ == '__main__':
    index()


import importlib
import yaml
import xhlog as log
from flask import Flask
def register_plugins(app: Flask):
    """
    ApiCat-接口猫 插件注册
    参数：
    app:flask实例
    返回：无
    """
    
    with open('plugins.yaml', encoding="utf-8") as f:
        data = yaml.load(f, Loader=yaml.FullLoader)
    plugin_list = list(data.keys())
    for plugin_name in plugin_list:
        try:
            plugin_module = importlib.import_module(str(plugin_name))
            blueprint = getattr(plugin_module, 'blueprint', None)
            if blueprint:
                blueprint.name = plugin_name
                app.register_blueprint(blueprint)
            else:
                log.warning(f"{plugin_name} 不是一个有效的apicat插件。")
        except ImportError:
            log.error(f"找不到插件 {plugin_name}。")


from flask import Flask, render_template_string
from importlib import import_module
from . import core, config
import xhlog as log

app = Flask("ApiCat")

@app.route('/')
def docs():
    plugin_docs = {}
    for blueprint_name in app.blueprints:
        module_name = blueprint_name.replace('-', '_')  # 转换为模块导入格式
        try:
            module = import_module(module_name)
            plugin_docs[blueprint_name] = getattr(module, 'docs', None)
        except (ImportError, AttributeError):
            log.error(f"插件 {blueprint_name} 没有文档。")

    combined_html = f"""
        <!DOCTYPE html>
        <html>
        <head>
            <title>{config.get_website_name()}</title>
        </head>
        <body>
            <h1>{config.get_website_name()}</h1>
            """

    for plugin_name, docs_func in plugin_docs.items():
        docs_str = docs_func() if callable(docs_func) else str(docs_func)
        combined_html += f"""
            <div class="api-docs">
                <p>{docs_str}</p>
            </div>
            """

    combined_html += """
            <br>
            <footer>
                <p>Powered by <a href="https://github.com/xinghai-osc/apicat">ApiCat</a></p>
            </footer>
        </body>
        <style>
    body {
        font-family: Arial, sans-serif;
        line-height: 1.6;
        color: #333;
        margin: 0;
        padding: 0;
        box-sizing: border-box;
    }

    /* 主标题样式 */
    h1 {
        font-size: 2rem;
        text-align: center;
        margin-top: 2rem;
        margin-bottom: 1rem;
    }

    /* API文档容器 */
    .api-docs {
        background-color: #f9f9f9;
        border-radius: 5px;
        padding: 15px;
        margin: 10px 0;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    /* 文本内容 */
    p {
        margin-bottom: 1rem;
    }

    /* 底部信息 */
    footer {
        text-align: center;
        margin-top: 3rem;
        color: #777;
    }
    
    /* "Powered by" 链接样式 */
    footer a {
        color: #007BFF;
        text-decoration: none;
    }
    
    footer a:hover {
        text-decoration: underline;
    }

    /* 响应式设计 */
    @media (max-width: 768px) {
        h1 {
            font-size: 1.5rem;
        }
        
        .plugin-docs {
            padding: 10px;
        }
    }
</style>
        </html>
        """
    return render_template_string(combined_html)



import toml,os

path = os.getcwd() + "\\config.toml"

def get_port():
    """获取端口，若不存在则返回80"""
    try:
        config = toml.load(path)
        return config['website']['port']
    except KeyError:
        return 80

def get_host():
    """获取主机地址，若不存在则返回'0.0.0.0'"""
    try:
        config = toml.load(path)
        return config['website']['host']
    except KeyError:
        return "0.0.0.0"

def get_website_name():
    """获取网站名称，若不存在则返回'ApiCat'"""
    try:
        config = toml.load(path)
        return config['website']['name']
    except KeyError:
        return "ApiCat"

def get_website_url():
    """获取网站URL，若不存在则返回'0.0.0.0'"""
    try:
        config = toml.load(path)
        return config['website']['url']
    except KeyError:
        return "0.0.0.0"

def get_plugin_cfg(name, type, default=None):
    """获取插件配置，若不存在则返回默认值"""
    try:
        config = toml.load(path)
        return config[name][type]
    except KeyError:
        return default